@@ -1,17 +1,10 @@
 /*
- *
- * Copyright (C) 2003-2007 Sebastian Trueg <trueg@k3b.org>
- * Copyright (C) 2010 Michal Malek <michalm@jabster.pl>
- *
- * This file is part of the K3b project.
- * Copyright (C) 1998-2010 Sebastian Trueg <trueg@k3b.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- * See the file "COPYING" for the exact licensing terms.
- */
+    SPDX-FileCopyrightText: 2003-2007 Sebastian Trueg <trueg@k3b.org>
+    SPDX-FileCopyrightText: 2010 Michal Malek <michalm@jabster.pl>
+    SPDX-FileCopyrightText: 1998-2010 Sebastian Trueg <trueg@k3b.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "k3bbootimagedialog.h"
 #include "k3bbootimagemodel.h"
@@ -105,26 +98,26 @@ void K3b::BootImageDialog::slotNewBootImage()
         if( fsize != 1200*1024 &&
             fsize != 1440*1024 &&
             fsize != 2880*1024 ) {
-            switch( KMessageBox::warningYesNoCancel( this,
-                                                     i18n("<p>The file you selected is not a floppy image (floppy images are "
-                                                          "of size 1200 KB, 1440 KB, or 2880 KB). You may still use boot images "
-                                                          "of other sizes by emulating a harddisk or disabling emulation completely. "
-                                                          "<p>If you are not familiar with terms like 'harddisk emulation' you most "
-                                                          "likely want to use a floppy image here. Floppy images can be created by "
-                                                          "directly extracting them from a real floppy disk:"
-                                                          "<pre>dd if=/dev/floppy of=/tmp/floppy.img</pre>"
-                                                          "or by using one of the many boot floppy generators that can be found on "
-                                                          "<a href=\"https://www.google.com/search?q=linux+boot+floppy&ie=UTF-8&oe=UTF-8\">the Internet</a>."),
-                                                     i18n("No Floppy image selected"),
-                                                     KGuiItem( i18n("Use harddisk emulation") ),
-                                                     KGuiItem( i18n("Use no emulation") ),
-                                                     KStandardGuiItem::cancel(),
-                                                     QString(),
-                                                     KMessageBox::AllowLink ) ) {
-            case KMessageBox::Yes:
+            switch( KMessageBox::warningTwoActionsCancel( this,
+                                                          i18n("<p>The file you selected is not a floppy image (floppy images are "
+                                                               "of size 1200 KB, 1440 KB, or 2880 KB). You may still use boot images "
+                                                               "of other sizes by emulating a harddisk or disabling emulation completely. "
+                                                               "<p>If you are not familiar with terms like 'harddisk emulation' you most "
+                                                               "likely want to use a floppy image here. Floppy images can be created by "
+                                                               "directly extracting them from a real floppy disk:"
+                                                               "<pre>dd if=/dev/floppy of=/tmp/floppy.img</pre>"
+                                                               "or by using one of the many boot floppy generators that can be found on "
+                                                               "<a href=\"https://www.google.com/search?q=linux+boot+floppy&ie=UTF-8&oe=UTF-8\">the Internet</a>."),
+                                                          i18n("No Floppy image selected"),
+                                                          KGuiItem( i18n("Use harddisk emulation") ),
+                                                          KGuiItem( i18n("Use no emulation") ),
+                                                          KStandardGuiItem::cancel(),
+                                                          QString(),
+                                                          KMessageBox::AllowLink ) ) {
+            case KMessageBox::PrimaryAction:
                 boottype = K3b::BootItem::HARDDISK;
                 break;
-            case KMessageBox::No:
+            case KMessageBox::SecondaryAction:
                 boottype = K3b::BootItem::NONE;
                 break;
             default:
@@ -224,4 +217,4 @@ void K3b::BootImageDialog::slotNoEmulationToggled( bool on )
         m_checkNoBoot->setChecked(false);
 }
 
-
+#include "moc_k3bbootimagedialog.cpp"
